package com.ruoyi.project.training.newstaff.service;

import java.util.List;
import com.ruoyi.project.training.newstaff.domain.TTnFirstplan;

/**
 * 进组培训Service接口
 * 
 * @author ruoyi
 * @date 2023-07-04
 */
public interface ITTnFirstplanService 
{
    /**
     * 查询进组培训
     * 
     * @param id 进组培训ID
     * @return 进组培训
     */
    public TTnFirstplan selectTTnFirstplanById(Long id);

    /**
     * 查询进组培训列表
     * 
     * @param tTnFirstplan 进组培训
     * @return 进组培训集合
     */
    public List<TTnFirstplan> selectTTnFirstplanList(TTnFirstplan tTnFirstplan);

    /**
     * 新增进组培训
     * 
     * @param tTnFirstplan 进组培训
     * @return 结果
     */
    public int insertTTnFirstplan(TTnFirstplan tTnFirstplan);

    /**
     * 修改进组培训
     * 
     * @param tTnFirstplan 进组培训
     * @return 结果
     */
    public int updateTTnFirstplan(TTnFirstplan tTnFirstplan);

    /**
     * 批量删除进组培训
     * 
     * @param ids 需要删除的进组培训ID
     * @return 结果
     */
    public int deleteTTnFirstplanByIds(Long[] ids);

    /**
     * 删除进组培训信息
     * 
     * @param id 进组培训ID
     * @return 结果
     */
    public int deleteTTnFirstplanById(Long id);

    int batchStatusTTnFirstplanByids(Long[] ids);
}
